==> emacs-goodies-el_31.4ubuntu1.tar.gz: emacs-goodies-el-31.4/elisp/emacs-goodies-el/pod-mode.el <==
;;; pod-mode.el --- Major mode for editing .pod-files

;;; It mainly defines a grammar for syntax highlighting.
;;; POD is the Plain Old Documentation format of Perl.

;;; Copyright 2003-2008 Steffen Schwigon

;;; Author: Steffen Schwigon <ss5@renormalist.net>
;;; Version: 0.502
;;; Keywords: perl pod
;;; X-URL: http://search.cpan.org/~schwigon/pod-mode/

;;; This program is free software; you can redistribute it and/or modify
;;; it under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 2, or (at your option)
;;; any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

;;; Tested on i386-linux with XEmacs 21.4.
;;; Tested on i386-linux with GNU Emacs 21.2.1.
;;; Tested on i386-windows-2k with XEmacs 21.4.

;;; Commentary:

;;; This mode is built with help of the
;;; "Emacs language mode creation tutorial" at
;;;
;;;   http://two-wugs.net/emacs/mode-tutorial.html
;;;
;;; which disapeared from the net and is now hosted at
;;;
;;;   http://renormalist.net/cgi-bin/twiki/view/Renormalist/EmacsLanguageModeCreationTutorial
;;;
;;; Regexes are defined for the following font-lock-faces:
;;;
;;;   font-lock-keyword-face
;;;   font-lock-type-face
;;;   font-lock-comment-face
;;;   font-lock-reference-face
;;;   font-lock-doc-string-face
;;;   font-lock-function-name-face
;;;

;;; Usage:

;;; Put this file into your load-path and the following into your ~/.emacs:
;;;
;;;    (require 'pod-mode)
;;;
;;;
;;; To associate pod-mode with .pod files add the following to your ~/.emacs
;;;
;;;    (setq auto-mode-alist
;;;       (append auto-mode-alist
;;;         '(("\\.pod$" . pod-mode))))
;;;
;;;
;;; To automatically turn on font-lock-mode add the following to your ~/.emacs
;;;
;;;    (add-hook 'pod-mode-hook 'font-lock-mode)
;;;

;;; Code:

;; default variables
(defvar pod-mode-hook nil)

;; keymap
(defvar pod-mode-map nil "Keymap for POD major mode.")
(if pod-mode-map nil
  (let ((map (make-sparse-keymap)))
    ;; insert (define-key map ...) stuff here
    (setq pod-mode-map map)))

;; syntax highlighting: standard keywords
(defconst pod-font-lock-keywords-1
  '(
    ("^=\\(head[1234]\\|item\\|over\\|back\\|cut\\|pod\\|for\\|begin\\|end\\|encoding\\)" 0 font-lock-keyword-face)
    ("^[ \t]+\\(.*\\)$" 1 font-lock-type-face)
    )
  "Minimal highlighting expressions for POD mode.")

;; syntax highlighting: additional keywords
(defconst pod-font-lock-keywords-2
  (append pod-font-lock-keywords-1
	  '(
	    ("^=\\(head[1234]\\|item\\|over\\|back\\|cut\\|pod\\|for\\|begin\\|end\\)\\(.*\\)" 2 font-lock-comment-face)
	    ))
  "Additional Keywords to highlight in POD mode.")

;; syntax highlighting: even more keywords
(defconst pod-font-lock-keywords-3
  (append pod-font-lock-keywords-2
	  '(
	    ("[IBCFXZS]<\\([^>]*\\)>" 1 font-lock-reference-face)
	    ("L<\\(\\([^|>]*\\)|\\)\\([^>]+\\)>"
	     (2 font-lock-reference-face)
	     (3 font-lock-function-name-face))
	    ("L<\\([^|>]+\\)>" 1 font-lock-function-name-face)
	    ("E<\\([^>]*\\)>" 1 font-lock-function-name-face)
	    ("\"\\([^\"]+\\)\"" 0 font-lock-string-face)
	    ))
  "Balls-out highlighting in POD mode.")

;; default level of highlight to maximum
(defvar pod-font-lock-keywords pod-font-lock-keywords-3
  "Default highlighting expressions for POD mode")

;; no special indenting, just pure text mode
(defun pod-indent-line ()
  "Indent current line as POD code. Does nothing yet."
  (interactive)
  )

;; no special syntax table
(defvar pod-mode-syntax-table nil
  "Syntax table for pod-mode.")

;; create and activate syntax table
(defun pod-create-syntax-table ()
  (if pod-mode-syntax-table
      ()
    (setq pod-mode-syntax-table (make-syntax-table))
    (set-syntax-table pod-mode-syntax-table)
    ))

(defun pod-add-support-for-outline-minor-mode ()
  "Provides additional menus from =head lines in outline-minor-mode"
  (make-local-variable 'outline-regexp)
  (setq outline-regexp "=head[1234] ")
  (make-local-variable 'outline-level)
  (setq outline-level
        (function (lambda ()
                    (save-excursion
                      (string-to-int (buffer-substring (+ (point) 5) (+ (point) 6)))
                      ))))
  )

;; main
(defun pod-mode ()
  "Major mode for editing POD files (Plain Old Documentation for Perl)."
  (interactive)
  (kill-all-local-variables)
  (pod-create-syntax-table)
  (use-local-map pod-mode-map)
  (make-local-variable 'font-lock-defaults)
  (setq font-lock-defaults '(pod-font-lock-keywords 't))
  ;; (make-local-variable 'indent-line-function)
  ;; (setq indent-line-function 'pod-indent-line)
  (setq major-mode 'pod-mode)
  (setq mode-name "POD")
  (setq imenu-generic-expression '((nil "^=head[1234] +\\(.*\\)" 1)))
  (run-hooks 'pod-mode-hook)
  (pod-add-support-for-outline-minor-mode)
  )

(provide 'pod-mode)

;;; pod-mode.el ends here

==> emacs-goodies-el_33.6ubuntu1.tar.gz: emacs-goodies-el-33.6/elisp/emacs-goodies-el/pod-mode.el <==
;;; pod-mode.el --- Major mode for editing .pod-files

;;; POD is the Plain Old Documentation format of Perl.

;;; Copyright 2003-2010 Steffen Schwigon

;;; Author: Steffen Schwigon <ss5@renormalist.net>
;;;
;;; Keywords: emacs mode perl pod
;;; X-URL: http://search.cpan.org/~schwigon/pod-mode/

;;; This program is free software; you can redistribute it and/or modify
;;; it under the terms of the GNU General Public License as published by
;;; the Free Software Foundation; either version 2, or (at your option)
;;; any later version.
;;;
;;; This program is distributed in the hope that it will be useful,
;;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;;; GNU General Public License for more details.
;;;
;;; You should have received a copy of the GNU General Public License
;;; along with this program; if not, write to the Free Software
;;; Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

;;; Tested on i386-linux with XEmacs 21.4.
;;; Tested on i386-linux with GNU Emacs 21.2.1.
;;; Tested on i386-windows-2k with XEmacs 21.4.

;;; Commentary:

;;; This mode is built with help of the
;;; "Emacs language mode creation tutorial" at
;;;
;;;   http://two-wugs.net/emacs/mode-tutorial.html
;;;
;;; which disapeared from the net and is now hosted at
;;;
;;;   http://renormalist.net/Renormalist/EmacsLanguageModeCreationTutorial
;;;
;;; Regexes are defined for the following font-lock-faces:
;;;
;;;   font-lock-keyword-face
;;;   font-lock-type-face
;;;   font-lock-comment-face
;;;   font-lock-reference-face
;;;   font-lock-doc-string-face
;;;   font-lock-function-name-face
;;;

;;; Usage:

;;; Put this file into your load-path and the following into your ~/.emacs:
;;;
;;;    (require 'pod-mode)
;;;
;;;
;;; To associate pod-mode with .pod files add the following to your ~/.emacs
;;;
;;;    (setq auto-mode-alist
;;;       (append auto-mode-alist
;;;         '(("\\.pod$" . pod-mode))))
;;;
;;;
;;; To automatically turn on font-lock-mode add the following to your ~/.emacs
;;;
;;;    (add-hook 'pod-mode-hook 'font-lock-mode)
;;;

;;; Code:

;; default variables
(defvar pod-mode-hook nil)

;;; Version: 1.01
(defvar pod-version "1.01"
  "Version of POD mode")

;; keymap
(defvar pod-mode-map nil "Keymap for POD major mode.")
(if pod-mode-map nil
  (let ((map (make-sparse-keymap)))
    ;; insert (define-key map ...) stuff here
    (setq pod-mode-map map)))

;; syntax highlighting: standard keywords
(defconst pod-font-lock-keywords-1
  '(
    ("^=\\(head[1234]\\|item\\|over\\|back\\|cut\\|pod\\|for\\|begin\\|end\\|encoding\\)" 0 font-lock-keyword-face)
    ("^[ \t]+\\(.*\\)$" 1 font-lock-type-face)
    )
  "Minimal highlighting expressions for POD mode.")

;; syntax highlighting: additional keywords
(defconst pod-font-lock-keywords-2
  (append pod-font-lock-keywords-1
	  '(
	    ("^=\\(head[1234]\\|item\\|over\\|back\\|cut\\|pod\\|for\\|begin\\|end\\)\\(.*\\)" 2 font-lock-comment-face)
	    ))
  "Additional Keywords to highlight in POD mode.")

;; syntax highlighting: even more keywords
(defconst pod-font-lock-keywords-3
  (append pod-font-lock-keywords-2
	  '(
	    ("[IBCFXZS]<\\([^>]*\\)>" 1 font-lock-reference-face)
	    ("L<\\(\\([^|>]*\\)|\\)\\([^>]+\\)>"
	     (2 font-lock-reference-face)
	     (3 font-lock-function-name-face))
	    ("L<\\([^|>]+\\)>" 1 font-lock-function-name-face)
	    ("E<\\([^>]*\\)>" 1 font-lock-function-name-face)
	    ("\"\\([^\"]+\\)\"" 0 font-lock-string-face)
	    ))
  "Balls-out highlighting in POD mode.")

;; default level of highlight to maximum
(defvar pod-font-lock-keywords pod-font-lock-keywords-3
  "Default highlighting expressions for POD mode")

;; no special indenting, just pure text mode
(defun pod-indent-line ()
  "Indent current line as POD code. Does nothing yet."
  (interactive)
  )

;; no special syntax table
(defvar pod-mode-syntax-table nil
  "Syntax table for pod-mode.")

;; create and activate syntax table
(defun pod-create-syntax-table ()
  (if pod-mode-syntax-table
      ()
    (setq pod-mode-syntax-table (make-syntax-table))
    (set-syntax-table pod-mode-syntax-table)
    ))

(defun pod-add-support-for-outline-minor-mode ()
  "Provides additional menus from =head lines in outline-minor-mode"
  (make-local-variable 'outline-regexp)
  (setq outline-regexp "=head[1234] ")
  (make-local-variable 'outline-level)
  (setq outline-level
        (function (lambda ()
                    (save-excursion
                      (string-to-int (buffer-substring (+ (point) 5) (+ (point) 6)))
                      ))))
  )

(defun pod-enable-weaver-collector-keywords (collectors)
  (let* ((keyword-list (mapcar (lambda (collector)
                                 (symbol-name (getf collector 'command)))
                               collectors))
         (keyword-re (concat "^=" (regexp-opt keyword-list t))))
    (setf pod-font-lock-keywords
          (append pod-font-lock-keywords
                  `((,keyword-re 0 font-lock-keyword-face))
                  `((,(concat keyword-re "\\(.*\\)") 2 font-lock-comment-face))))
    (setq font-lock-mode-major-mode nil)
    (font-lock-fontify-buffer)))

(defun pod-enable-weaver-features (weaver-config)
  (pod-enable-weaver-collector-keywords (getf weaver-config 'collectors))
  (message "Pod::Weaver keywords loaded."))

(defvar pod-weaver-config-buffer "")

(defun pod-load-weaver-config (dir)
  "Load additional pod keywords from a projects dist.ini/weaver.ini"
  (let* ((proc (start-process-shell-command
                (concat "weaverconf-" (buffer-name (current-buffer)))
                nil (format "cd %s; dzil weaverconf -f lisp" dir))))
    (make-local-variable 'pod-weaver-config-buffer)
    (set-process-filter
     proc (lambda (proc str)
            (setq pod-weaver-config-buffer (concat pod-weaver-config-buffer str))))
    (set-process-sentinel
     proc (lambda (proc event)
            (if (string-equal event "finished\n")
                (let ((weaver-config
                       (ignore-errors
                         (eval (car (read-from-string pod-weaver-config-buffer))))))
                  (if weaver-config (pod-enable-weaver-features weaver-config))))
            (setq pod-weaver-config-buffer "")))))

(defun pod-add-support-for-weaver ()
  (let ((project-root (ignore-errors (eproject-maybe-turn-on))))
    (if project-root (pod-load-weaver-config project-root))))

;; main
(defun pod-mode ()
  "Major mode for editing POD files (Plain Old Documentation for Perl)."
  (interactive)
  (kill-all-local-variables)
  (pod-create-syntax-table)
  (use-local-map pod-mode-map)
  (make-local-variable 'font-lock-defaults)
  (setq font-lock-defaults '(pod-font-lock-keywords 't))
  ;; (make-local-variable 'indent-line-function)
  ;; (setq indent-line-function 'pod-indent-line)
  (setq major-mode 'pod-mode)
  (setq mode-name "POD")
  (setq imenu-generic-expression '((nil "^=head[1234] +\\(.*\\)" 1)))
  (run-hooks 'pod-mode-hook)
  (pod-add-support-for-outline-minor-mode)
  (pod-add-support-for-weaver)
  )

(provide 'pod-mode)

;;; pod-mode.el ends here
